import React from 'react'
import { translate } from 'cozy-ui/react/I18n'
import { FluidType } from 'enum/fluid.enum'
import Tabs from 'components/CommonKit/Tabs/StyledTabs'
import Tab from 'components/CommonKit/Tabs/StyledTab'
import { TimeStep } from 'services/dataConsumptionContracts'

interface ConsumptionNavigatorProps {
  fluidTypes: FluidType[]
  multiFluid: boolean
  timeStep: TimeStep
  handleClickTimeStep(timeStep: TimeStep): void
  t: Function
}

const ConsumptionNavigator: React.FC<ConsumptionNavigatorProps> = ({
  fluidTypes,
  multiFluid,
  timeStep,
  handleClickTimeStep,
  t,
}: ConsumptionNavigatorProps) => {
  const fluidStyle = multiFluid
    ? 'MULTIFLUID'
    : fluidTypes.length === 0
    ? 'MULTIFLUID'
    : fluidTypes.length > 1
    ? 'MULTIFLUID'
    : FluidType[fluidTypes[0]]
  const handleClick = (timeStep: TimeStep) => {
    handleClickTimeStep(timeStep)
  }

  const defineNavTab = (fluidTypes: FluidType[]) => {
    if (multiFluid) {
      return [TimeStep.DAY, TimeStep.MONTH, TimeStep.YEAR]
    } else if (fluidTypes.length === 1) {
      switch (fluidTypes[0]) {
        case FluidType.ELECTRICITY:
          return [
            TimeStep.HALF_AN_HOUR,
            TimeStep.DAY,
            TimeStep.MONTH,
            TimeStep.YEAR,
          ]
        case FluidType.WATER:
          return [TimeStep.DAY, TimeStep.MONTH, TimeStep.YEAR]
        case FluidType.GAS:
          return [TimeStep.DAY, TimeStep.MONTH, TimeStep.YEAR]
      }
    }
    return [TimeStep.DAY, TimeStep.MONTH, TimeStep.YEAR]
  }

  const defineLabel = (dataTimeStep: TimeStep) => {
    const classes =
      dataTimeStep === timeStep
        ? `${fluidStyle.toLowerCase()} tab-text-on`
        : `${fluidStyle.toLowerCase()} tab-text-off`
    return (
      <span className={classes}>
        {t(`TIMESTEP.${TimeStep[dataTimeStep]}.STEP`)}
      </span>
    )
  }

  return (
    <div className="cn">
      <Tabs
        className="cn-tabs"
        value={timeStep}
        variant="fullWidth"
        fluidTypes={fluidTypes}
        multiFluid={multiFluid}
      >
        {defineNavTab(fluidTypes).map((dataTimeStep, index) => {
          return (
            <Tab
              className="cn-tab"
              key={index}
              value={dataTimeStep}
              fluidTypes={fluidTypes}
              multiFluid={multiFluid}
              label={defineLabel(dataTimeStep)}
              onClick={() => handleClick(dataTimeStep)}
            />
          )
        })}
      </Tabs>
    </div>
  )
}

export default translate()(ConsumptionNavigator)
